@@ -90,9 +90,6 @@ struct _GESPipelinePrivate
   GstEncodingProfile *profile;
 
   GThread *valid_thread;
-
-  GList *contexts;
-
 };
 
 enum
@@ -268,36 +265,6 @@ ges_pipeline_constructed (GObject * object)
   ((GObjectClass *) ges_pipeline_parent_class)->constructed (object);
 }
 
-static void
-ges_pipeline_update_context (GESPipeline * self, GstContext * context)
-{
-  GList *l;
-  const gchar *context_type;
-
-  GST_OBJECT_LOCK (self);
-  context_type = gst_context_get_context_type (context);
-  for (l = self->priv->contexts; l; l = l->next) {
-    GstContext *tmp = l->data;
-    const gchar *tmp_type = gst_context_get_context_type (tmp);
-
-    /* Always store newest context but never replace
-     * a persistent one by a non-persistent one */
-    if (strcmp (context_type, tmp_type) == 0 &&
-        (gst_context_is_persistent (context) ||
-            !gst_context_is_persistent (tmp))) {
-      gst_context_replace ((GstContext **) & l->data, context);
-      break;
-    }
-  }
-  /* Not found? Add */
-  if (l == NULL) {
-    self->priv->contexts =
-        g_list_prepend (self->priv->contexts, gst_context_ref (context));
-  }
-  GST_OBJECT_UNLOCK (self);
-}
-
-
 static void
 ges_pipeline_handle_message (GstBin * bin, GstMessage * msg)
 {
@@ -305,49 +272,58 @@ ges_pipeline_handle_message (GstBin * bin, GstMessage * msg)
 
   if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_NEED_CONTEXT) {
     const gchar *context_type;
-    GList *iter;
 
     gst_message_parse_context_type (msg, &context_type);
-    GST_OBJECT_LOCK (self);
-    for (iter = self->priv->contexts; iter; iter = g_list_next (iter)) {
-      GstContext *tmp = iter->data;
-      const gchar *tmp_type = gst_context_get_context_type (tmp);
+    /* Special handling for task pool context */
+    if (g_strcmp0 (context_type, GST_TASK_POOL_CONTEXT_TYPE) == 0) {
+      GstElement *child = GST_ELEMENT (GST_MESSAGE_SRC (msg));
+      GstContext *pool_context = NULL;
 
-      if (strcmp (context_type, tmp_type) == 0) {
-        GST_DEBUG_OBJECT (msg->src, "Setting context %s %" GST_PTR_FORMAT,
-            tmp_type, tmp);
-        gst_element_set_context (GST_ELEMENT (GST_MESSAGE_SRC (msg)), tmp);
-        break;
+      /* First check if we already have a task pool context */
+      pool_context =
+          gst_element_get_context (GST_ELEMENT_CAST (self),
+          GST_TASK_POOL_CONTEXT_TYPE);
+
+      if (!pool_context) {
+        GstMessage *new_msg;
+
+        new_msg = gst_message_new_need_context (GST_OBJECT_CAST (self),
+            GST_TASK_POOL_CONTEXT_TYPE);
+        gst_element_post_message (GST_ELEMENT_CAST (self), new_msg);
+
+        pool_context =
+            gst_element_get_context (GST_ELEMENT_CAST (self),
+            GST_TASK_POOL_CONTEXT_TYPE);
       }
-    }
-    GST_OBJECT_UNLOCK (self);
 
-    /* don't need to post upward this if it's answered by us */
-    if (iter) {
+      if (!pool_context) {
+        GstTaskPool *pool;
+        GstMessage *have_msg;
+
+        pool = gst_shared_task_pool_new ();
+        gst_shared_task_pool_set_max_threads (GST_SHARED_TASK_POOL (pool),
+            g_get_num_processors ());
+        gst_task_pool_prepare (pool, NULL);
+
+        pool_context = gst_context_new (GST_TASK_POOL_CONTEXT_TYPE, FALSE);
+        gst_context_set_task_pool (pool_context, pool);
+        gst_object_unref (pool);
+
+        have_msg =
+            gst_message_new_have_context (GST_OBJECT_CAST (self),
+            gst_context_ref (pool_context));
+        gst_element_post_message (GST_ELEMENT_CAST (self), have_msg);
+      }
+
+      gst_element_set_context (child, pool_context);
+      gst_context_unref (pool_context);
       gst_message_unref (msg);
-      msg = NULL;
+
+      return;
     }
-  } else if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_HAVE_CONTEXT) {
-    GstContext *context;
-
-    gst_message_parse_have_context (msg, &context);
-    ges_pipeline_update_context (self, context);
-    gst_context_unref (context);
   }
 
-  if (msg) {
-    GST_BIN_CLASS (ges_pipeline_parent_class)->handle_message (bin, msg);
-  }
-}
-
-static void
-ges_pipeline_finalize (GObject * object)
-{
-  GESPipeline *self = GES_PIPELINE (object);
-
-  g_list_free_full (self->priv->contexts, (GDestroyNotify) gst_context_unref);
-
-  G_OBJECT_CLASS (ges_pipeline_parent_class)->finalize (object);
+  GST_BIN_CLASS (ges_pipeline_parent_class)->handle_message (bin, msg);
 }
 
 static void
@@ -403,7 +379,6 @@ ges_pipeline_class_init (GESPipelineClass * klass)
 
   object_class->constructed = ges_pipeline_constructed;
   object_class->dispose = ges_pipeline_dispose;
-  object_class->finalize = ges_pipeline_finalize;
   object_class->get_property = ges_pipeline_get_property;
   object_class->set_property = ges_pipeline_set_property;
 
@@ -1592,39 +1567,12 @@ activate_sink_bus_handler (GstBus * bus, GstMessage * msg, GESPipeline * self)
       gst_element_post_message (GST_ELEMENT_CAST (self), msg);
     else
       gst_message_unref (msg);
-  } else if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_NEED_CONTEXT) {
-    const gchar *context_type;
-    GList *l;
-
-    gst_message_parse_context_type (msg, &context_type);
-    GST_OBJECT_LOCK (self);
-    for (l = self->priv->contexts; l; l = l->next) {
-      GstContext *tmp = l->data;
-      const gchar *tmp_type = gst_context_get_context_type (tmp);
-
-      if (strcmp (context_type, tmp_type) == 0) {
-        gst_element_set_context (GST_ELEMENT (GST_MESSAGE_SRC (msg)), l->data);
-        break;
-      }
-    }
-    GST_OBJECT_UNLOCK (self);
-
-    /* Forward if we couldn't answer the message */
-    if (l == NULL) {
-      gst_element_post_message (GST_ELEMENT_CAST (self), msg);
-    } else {
-      gst_message_unref (msg);
-    }
-  } else if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_HAVE_CONTEXT) {
-    GstContext *context;
-
-    gst_message_parse_have_context (msg, &context);
-    ges_pipeline_update_context (self, context);
-    gst_context_unref (context);
-
-    gst_element_post_message (GST_ELEMENT_CAST (self), msg);
   } else {
-    gst_element_post_message (GST_ELEMENT_CAST (self), msg);
+    GST_DEBUG_OBJECT (self,
+        "Posting %s from %" GST_PTR_FORMAT " directly to our child bus as the"
+        " sink is not in the bin yet but we need to handle its messages still",
+        GST_MESSAGE_TYPE_NAME (msg), msg->src ? msg->src : NULL);
+    gst_bus_post (GST_BIN (self)->child_bus, msg);
   }
 
   /* Doesn't really matter, nothing is using this bus */
