@@ -13,8 +13,9 @@ fill_pipeline_and_check (GstElement * comp, GList * segments,
   GList *listcopy = copy_segment_list (segments);
 
   pipeline = gst_pipeline_new ("test_pipeline");
-  sink = gst_element_factory_make_or_warn ("fakesink", "sink");
+  sink = gst_element_factory_make_or_warn ("fakevideosink", "sink");
   fail_if (sink == NULL);
+  g_object_set (sink, "sync", FALSE, NULL);
 
   gst_bin_add_many (GST_BIN (pipeline), comp, sink, NULL);
 
@@ -562,7 +563,8 @@ GST_START_TEST (test_renegotiation)
   ASSERT_OBJECT_REFCOUNT (source3, "source3", 1);
 
 
-  sink = gst_element_factory_make_or_warn ("fakesink", "sink");
+  sink = gst_element_factory_make_or_warn ("fakeaudiosink", "sink");
+  g_object_set (sink, "sync", FALSE, NULL);
   audioconvert = gst_element_factory_make_or_warn ("audioconvert", "aconv");
 
   gst_bin_add_many (GST_BIN (pipeline), comp, audioconvert, sink, NULL);
